@@ -14,7 +14,7 @@ FAST_API_SKILL_TEMPLATE_URL = ""
 about = {
     '__title__': 'scintillant',
     '__description__': 'Fast bot creating framework',
-    '__version__': '0.0.13.9',
+    '__version__': '0.0.14',
     '__author__': 'Niel Ketov',
     '__author_email__': 'ketov-x@yandex.ru',
     '__url__': 'https://code.tatar.ru/projects/LILIYA/repos/scintillant',
@@ -22,6 +22,6 @@ about = {
 }
 
 addons_versions = {
-    '__testsuite__': 'v0.0.1',
+    '__testsuite__': '0.13',
     '__bottle_skill_template__': ''
 }
